@@ -11,7 +11,7 @@ def get_engine():
 
     return sqlalchemy.create_engine(
         'sqlite:///%s' % os.path.join(os.environ.get('HOME'), 'qsc.dat'),
-        echo=True
+        echo=False
     )
 
 
