@@ -2,16 +2,16 @@
 import sys
 import logging
 
+VERSION = '0.3.5'
+DEBUG = False
+
+__version__ = VERSION
+
 
 class _System(object):
 
     _instance = None
 
-    _config_sections = [
-        'editor',
-        'menu'
-    ]
-
     def __new__(cls, *args, **kwargs):
         if not cls._instance:
             cls._instance = super(_System, cls).__new__(cls, *args, **kwargs)
